@@ -124,7 +124,7 @@ setMethod("as.longData","data.frame",
         if(missing(idAll)){idAll <- data[,1]}else{}
         if(missing(varNames)){varNames <- names(timeDataFrame)}else{}
         if(missing(time)){time <- 1:length(timeDataFrame[[1]])}else{}
-        matr <- as.matrix(data[,na.omit(unlist(timeDataFrame))])
+        matr <- as.matrix(data[,sort(na.omit(unlist(timeDataFrame)))])
         traj <- array(matr[,rank(unlist(timeDataFrame),na.last="keep")],c(length(idAll),length(time),length(varNames)))
         return(longData(traj=traj,idAll=idAll,time=time,varNames=varNames,maxNA=maxNA))
     }
